Test verifyEditable
open | ../tests/html/test_editable.html |
verifyEditable | normal_text |
verifyEditable | normal_select |
verifyNotEditable | disabled_text |
verifyNotEditable | disabled_select |
assertFailureOnNext | true |
verifyNotEditable | normal_text |
assertFailureOnNext | true |
verifyNotEditable | normal_select |
assertFailureOnNext | false |
verifyEditable | disabled_text |
assertFailureOnNext | false |
verifyEditable | disabled_select |
assertFailureOnNext | Element fake_input is not an input. |
verifyEditable | fake_input |